Exception: Emittance::IdentifierCollisionError

Inherits:
StandardError
  • Object
show all
Defined in:
lib/emittance/errors.rb

Overview

Raised when an identifier registration is attempted, but there exists an event registered to the given identifiered.